@@ -388,13 +388,20 @@ class kafka_mdml_consumer:
                         dat += files[fn][str(i+1)]
                     if value['encoding'] == 'base64':
                         dat_bytes = b64decode(dat)
-                        with open(f'{save_dir}/{os.path.basename(fn)}', 'wb') as f:
-                            f.write(dat_bytes)
+                        if save_file:
+                            with open(f'{save_dir}/{os.path.basename(fn)}', 'wb') as f:
+                                f.write(dat_bytes)
+                            ret = os.path.basename(fn)
+                        else:
+                            ret = dat_bytes
                     else:
-                        with open(f'{save_dir}/{os.path.basename(fn)}', 'w', encoding=value['encoding']) as f:
-                            f.write(dat_bytes)
+                        if save_file:
+                            with open(f'{save_dir}/{os.path.basename(fn)}', 'w', encoding=value['encoding']) as f:
+                                f.write(dat)
+                        else:
+                            ret = dat.decode(value['encoding'])                       
                     del files[fn]
-                    yield os.path.basename(fn)
+                    yield ret
             except KeyboardInterrupt:
                 break
 
